#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict

###############################################################
# USED TO GENERATE CODE SNIPPETS FOR THE OEDEPICT DOCUMENTATION
###############################################################


def DepictMoleculesWithHighlight(smiles, ss, highlight, basefilename):

    mol = oechem.OEGraphMol()
    oechem.OESmilesToMol(mol, smiles)
    oedepict.OEPrepareDepiction(mol)

    opts = oedepict.OE2DMolDisplayOptions(250, 160, oedepict.OEScale_AutoScale)
    opts.SetTitleLocation(oedepict.OETitleLocation_Hidden)
    disp = oedepict.OE2DMolDisplay(mol, opts)

    unique = True
    oedepict.OEAddHighlightOverlay(disp, highlight, ss.Match(mol, unique))

    image = oedepict.OEImage(disp.GetWidth(), disp.GetHeight())
    oedepict.OERenderMolecule(image, disp)

    oedepict.OEWriteImage(basefilename + ".png", image)
    oedepict.OEWriteImage(basefilename + ".pdf", image)


smiles = "c1cc(cc2c1ccc(c2)O)O"
ss = oechem.OESubSearch("c1ccc(O)cc1")


# @ <SNIPPET-OEHIGHLIGHTOVERLAYBYBALLANDSTICK-SETSTICKWIDTHSCALE>
highlight = oedepict.OEHighlightOverlayByBallAndStick(oechem.OEGetVividColors())
highlight.SetStickWidthScale(5.0)
# @ </SNIPPET-OEHIGHLIGHTOVERLAYBYBALLANDSTICK-SETSTICKWIDTHSCALE>
DepictMoleculesWithHighlight(smiles, ss, highlight,
                             "OEHighlightOverlayByBallAndStick_SetStickWidthScale")

# @ <SNIPPET-OEHIGHLIGHTOVERLAYBYBALLANDSTICK-SETBALLRADIUSSCALE>
highlight = oedepict.OEHighlightOverlayByBallAndStick(oechem.OEGetVividColors())
highlight.SetBallRadiusScale(4.0)
# @ </SNIPPET-OEHIGHLIGHTOVERLAYBYBALLANDSTICK-SETBALLRADIUSSCALE>
DepictMoleculesWithHighlight(smiles, ss, highlight,
                             "OEHighlightOverlayByBallAndStick_SetBallRadiusScale")

# @ <SNIPPET-OEHIGHLIGHTOVERLAYBYBALLANDSTICK-SETATOMLABELMONOCHROME>
highlight = oedepict.OEHighlightOverlayByBallAndStick(oechem.OEGetVividColors())
highlight.SetAtomLabelMonochrome(False)
# @ </SNIPPET-OEHIGHLIGHTOVERLAYBYBALLANDSTICK-SETATOMLABELMONOCHROME>
DepictMoleculesWithHighlight(smiles, ss, highlight,
                             "OEHighlightOverlayByBallAndStick_SetAtomLabelMonochrome")



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from openeye import oechem
from math import degrees

mol = oechem.OEMol()
o = mol.NewAtom(oechem.OEElemNo_O)
h1 = mol.NewAtom(oechem.OEElemNo_H)
h2 = mol.NewAtom(oechem.OEElemNo_H)

Acrds = [0.0, 0.0, 0.0,
         0.9584, 0.0, 0.0,
         -0.2392, 0.9281, 0.0]
# Grab the default conformer
Aconf = mol.GetConfs().next()
Aconf.SetCoords(oechem.OEFloatArray(Acrds))

Bcrds = [0.0, 0.0, 0.0,
         0.9584, 0.0, 0.0,
         -0.2392, -0.9281, 0.0]
Bconf = mol.NewConf(oechem.OEFloatArray(Bcrds))

print("1st Water Angle:", degrees(oechem.OEGetAngle(Aconf, h1, o, h2)))
print("2nd Water Angle:", degrees(oechem.OEGetAngle(Bconf, h1, o, h2)))
# @ </SNIPPET>



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from openeye import oechem

ifs = oechem.oemolistream()

flavor = (oechem.OEIFlavor_Generic_Default |
          oechem.OEIFlavor_FASTA_CustomResidues |
          oechem.OEIFlavor_FASTA_EmbeddedSMILES)

ifs.SetFlavor(oechem.OEFormat_FASTA, flavor)
ifs.SetFormat(oechem.OEFormat_FASTA)

oechem.OEAddCustomFASTAResidue("dI", "CC[C@@H](C)[C@@H](C(=O)O)N")

custom_fasta = """>Custom FASTA
FVVVSTDPWVNGLY[dI]D[NC(=O)CNC(=O)[C@@H](N[R16])CSCC(=O)[R1]]"""

ifs.openstring(custom_fasta)

mol = oechem.OEGraphMol()
oechem.OEReadMolecule(ifs, mol)
# @ </SNIPPET>
